
/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/

#include <vector>
#include <pappsomspp/types.h>
#include "proteinxtp.h"
#include "peptidematch.h"
#include "automaticfilterparameters.h"
#include "../grouping/groupingexperiment.h"

#ifndef PROTEINMATCH_H
#define PROTEINMATCH_H

class ProteinMatch
{
public:
    ProteinMatch();
    ~ProteinMatch();

    const ProteinXtpSp & getProteinXtpSp() const;
    void setEvalue(pappso::pappso_double evalue);
    pappso::pappso_double getEvalue() const;
    void setProteinXtpSp(ProteinXtpSp protein_sp);
    void addPeptideMatch(PeptideMatch * peptide_match);
    std::vector<PeptideMatch *> & getPeptideMatchList();
    void setChecked(bool arg1);

    bool isChecked() const;
    bool isValid() const;
    bool isValidAndChecked() const;

    /** @brief validate or invalidate peptides and proteins based automatic filters and manual checks
    * */
    void updateAutomaticFilters(const AutomaticFilterParameters & automatic_filter_parameters);

    void setGroupingExperiment(GroupingExperiment * p_grp_experiment);
    
    QString getStringGroupSubgroupNumber() const;

private:
    pappso::GrpProteinSp _sp_grp_protein;

    std::vector<PeptideMatch *> _peptide_match_list;
    ProteinXtpSp _protein_sp = nullptr;
    pappso::pappso_double _evalue=0;
    /** @brief manually checked by user (true by default)
     */
    bool _checked = true;

    /** @brief automatic filter result (false by default)
     */
    bool _proxy_valid = false;

};

#endif // PROTEINMATCH_H
